Crate map1

This crate houses several wrappers and convenience macros over std collections that guarantee that they will never be empty. This is particularly useful for modeling APIs and data that need a non-empty invariant and reducing potential error cases by using types rather than conventions.

The crate provides an optional serde feature, which provides implementations of serde::Serialize/serde::Deserialize.

Re-exports

Modules

Macros

  • A convenience macro for constructing BTreeMap1.